<?php

/**
 * Register customizer panels, sections, settings, and controls.
 *
 * @since  1.0.0
 * @access public
 * @param  object  $wp_customize
 * @return void
 */
# Register our customizer panels, sections, settings, and controls.
require get_template_directory() . '/assets/components/typography/google-fonts-list.php';

add_action('customize_register', 'sakala_typography_customize_register', 15);

function sakala_typography_customize_register($wp_customize) {

    require get_template_directory() . '/assets/components/typography/customizer-typography-control-class.php';

    // Register typography control JS template.
    $wp_customize->register_control_type('Sakala_Typography_Control');

    // Add the typography panel.
    $wp_customize->add_panel('typography', array(
        'priority' => 100,
        'title' => esc_html__('Typography Options', 'sakala')
    ));

    $wp_customize->add_section('body_typography', array(
        'panel' => 'typography',
        'title' => esc_html__('Body', 'sakala')
    ));

    $wp_customize->add_setting('body_font_family', array(
        'default' => 'sans-serif',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_setting('body_font_style', array(
        'default' => '400',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_setting('body_text_decoration', array(
        'default' => 'none',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_setting('body_text_transform', array(
        'default' => 'none',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_setting('body_font_size', array(
        'default' => '16',
        'sanitize_callback' => 'absint',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_setting('body_line_height', array(
        'default' => '1.5',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));
    
    $wp_customize->add_setting('body_letter_spacing', array(
        'default' => '1',
        'sanitize_callback' => 'sanitize_text_field',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_setting('body_color', array(
        'default' => '#404040',
        'sanitize_callback' => 'sanitize_hex_color',
        'transport' => 'postMessage'
    ));

    $wp_customize->add_control(new Sakala_Typography_Control($wp_customize, 'body_typography', array(
        'label' => esc_html__('Body Typography', 'sakala'),
        'description' => __('Select how you want your body to appear.', 'sakala'),
        'section' => 'body_typography',
        'settings' => array(
            'family' => 'body_font_family',
            'style' => 'body_font_style',
            'text_decoration' => 'body_text_decoration',
            'text_transform' => 'body_text_transform',
            'size' => 'body_font_size',
            'line_height' => 'body_line_height',
            'letter_spacing' => 'body_letter_spacing',
            'typocolor' => 'body_color'
        ),
        'input_attrs' => array(
            'min' => 10,
            'max' => 40,
            'step' => 1
        )
    )));
  
}

/**
 * Register control scripts/styles.
 *
 */
add_action('customize_controls_enqueue_scripts', 'sakala_typography_customizer_script');

function sakala_typography_customizer_script() {
    wp_enqueue_script('sakala-customize-controls', get_template_directory_uri() . '/assets/components/typography/js/customize-controls.js', array('jquery'), '1.0.0', true);
    wp_enqueue_style('sakala-customize-controls', get_template_directory_uri() . '/assets/components/typography/css/customize-controls.css');
}

/**
 * Load preview scripts/styles.
 *
 */
add_action('customize_preview_init', 'sakala_typography_customize_preview_script');

function sakala_typography_customize_preview_script() {
    wp_enqueue_script('webfont', 'https://ajax.googleapis.com/ajax/libs/webfont/1.6.26/webfont.js', array('jquery'));
    wp_enqueue_script('sakala-customize-preview', get_template_directory_uri() . '/assets/components/typography/js/customize-previews.js', array('jquery', 'customize-preview', 'webfont'));
}

function sakala_get_google_font_variants() {

    $font_list = array_merge(sakala_standard_font_array(), sakala_google_font_array());

    $font_family = $_REQUEST['font_family'];
    $font_array = sakala_search_key($font_list, 'family', $font_family);

    $variants_array = $font_array['0']['variants'];
    $options_array = "";
    foreach ($variants_array as $key => $variants) {
        $selected = $key == '400' ? 'selected="selected"' : '';
        $options_array .= '<option ' . $selected . ' value="' . $key . '">' . $variants . '</option>';
    }

    if (!empty($options_array)) {
        echo $options_array;
    } else {
        echo $options_array = '';
    }
    die();
}

add_action("wp_ajax_get_google_font_variants", "sakala_get_google_font_variants");

function sakala_search_key($array, $key, $value) {
    $results = array();
    if (is_array($array)) {
        if (isset($array[$key]) && $array[$key] == $value) {
            $results[] = $array;
        }
        foreach ($array as $subarray) {
            $results = array_merge($results, sakala_search_key($subarray, $key, $value));
        }
    }
    return $results;
}

function sakala_body_class( $classes ) {
    return array_merge( $classes, array( 'sakalatypg' ) );
}
add_filter( 'body_class', 'sakala_body_class' );