<?php
/*Add New Panel for footer Setups */
$wp_customize->add_panel( 'sakala_footer_panel', array (
	'priority' => '20',
	'capability' => 'edit_theme_options',
	'theme_supports' => '',
	'title' => __( 'Footer Settings', 'sakala' ),
	'description' => __( 'Setup footer of the site.', 'sakala' )
) );

/* footer Section */
$wp_customize->add_section( 'sakala_footer_section', array(
	'title' => __('Footer Layouts', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_footer_panel',
	'priority' => 10,
) );

$wp_customize->add_setting( 'sakala_footer_layout_setting', array( 
	'default' 			=> 'lay2',
	'sanitize_callback' => 'sakala_sanitize_layout' 
) );

$sakala_footer_layouts = array();
for($i=1;$i<=3;$i++){
	$sakala_footer_layouts['lay'.$i] = array(
		'image'=> get_template_directory_uri().'/assets/images/sakala-footer'.$i.'.png',
		'name'=>__('Layout ', 'sakala').$i,
	);
}

$wp_customize->add_control( new Image_Radio_Buttons( $wp_customize, 'sakala_footer_layout_setting', array(
	'type' => 'image_radio_buttons',
	'label' => __( 'Footer Layouts', 'sakala' ),
	'section' => 'sakala_footer_section',
	'choices' => $sakala_footer_layouts,
	'changednd' => 'change-layout',
) ) );


/** Footer Individual Section designs */
$footer_sections = array(
	'top_footer'=>__('Top Footer','sakala'),
	'main_footer'=>__('Main Footer','sakala')
);

foreach ($footer_sections as $fsec => $ftitle) {

	$wp_customize->add_section( 'sakala_'.$fsec.'_section_designs', array(
		'title' => $ftitle.' '.__('Designs', 'sakala' ),
		'capability' => 'edit_theme_options',
		'panel' => 'sakala_footer_panel',
		'priority' => 20,
	) );

	$wp_customize->add_setting( 'sakala_footer_style_'.$fsec, array( 
		'default' 			=> 'sakala-wrapper',
		'sanitize_callback' => 'sakala_sanitize_wrapper' 
	) );

	$wp_customize->add_control( 'sakala_footer_style_'.$fsec, array(
		'label'    => $ftitle.' '.__( 'Wrapper Style','sakala'),
		'section' => 'sakala_'.$fsec.'_section_designs',
		'type'    => 'select',
		'choices' => array(
			'sakala-wrapper' => esc_html__( 'Wrapped', 'sakala' ),
			'sakala-fullwidth' => esc_html__( 'Fullwidth', 'sakala' ),
		),
	) );

	/* footer */
	$wp_customize->add_setting( 'sakala_footer_width_'.$fsec, array( 
		'default' 			=> '1200',
		'transport'			=> 'postMessage',
		'sanitize_callback' => 'sakala_sanitize_integer' 
	) );

	$wp_customize->add_control( new Slider_Control( $wp_customize, 'sakala_footer_width_'.$fsec, array(
		'type'     => 'slider_control',
		'section'  => 'sakala_'.$fsec.'_section_designs',
		'label'    => $ftitle.' '.__( 'Wrapper Width','sakala'),
		'input_attrs' => array(
			'min'    => 800,
			'max'    => 1920,
			'step'   => 1,
			'suffix' => 'px',
		),
		'active_callback' => 'wrap_sakala_footer_style_'.$fsec
	) ) );

	$wp_customize->add_setting( 'sakala_footer_bkgcolor_'.$fsec, array( 
		'default' 			=> '',
		'transport' 	=> 'postMessage',
		'sanitize_callback' => 'sakala_sanitize_text' 
	) );

	$wp_customize->add_control( new Customize_Alpha_Color_Control($wp_customize, 'sakala_footer_bkgcolor_'.$fsec, array(
		'label'    => $ftitle.' '.__( 'Background Color','sakala'),
		'section'  => 'sakala_'.$fsec.'_section_designs',
		'show_opacity'  => true,
		'palette'	=> array(
			'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
			'rgba(50,50,50,0.8)',
			'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
			'#00CC99' // Mix of color types = no problem
		)
	) ) );

	$wp_customize->add_setting( 'sakala_footer_marginpadding_'.$fsec, array(
		'default'           => '0, -, 0, -, 0, 0, 0, 0',
		'transport'			=> 'postMessage',
		'sanitize_callback' => 'sakala_sanitize_text',
	) );

	$wp_customize->add_control( new Box_Model( $wp_customize, 'sakala_footer_marginpadding_'.$fsec, array(
		'label'       => $ftitle.' '.esc_html__( 'Margin and Padding', 'sakala' ),
		'description' => esc_html__( 'Set the default margin and padding.', 'sakala' ),
		'choices'    => array(
			'margin' => array(
				'margin-top'     => '',
				'margin-right'   => '',
				'margin-bottom'  => '',
				'margin-left'    => '',
			),
			'padding' => array(
				'padding-top'    => '',
				'padding-right'  => '',
				'padding-bottom' => '',
				'padding-left'   => '',
			),
		),
		'section'     => 'sakala_'.$fsec.'_section_designs',
	) ) );
}


/* Footer Elements */
$wp_customize->add_panel( 'sakala_footer_elements', array (
	'priority' => '20',
	'capability' => 'edit_theme_options',
	'theme_supports' => '',
	'title' => __( 'Footer Elements', 'sakala' ),
	'description' => __( 'Setup Footer Elements of the site.', 'sakala' )
) );

$wp_customize->add_section( 'sakala_footer_menu_section', array(
	'title' => __('Footer Menu', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_footer_elements',
	'priority' => sakala_get_section_position( 'sakala_footer_menu_section','footer' ),
) );

$wp_customize->add_setting( 'sakala_footer_menu', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_integer' 
) );

$wp_customize->add_control( new Info_Custom_Control( $wp_customize, 'sakala_footer_menu', array(
	'type'     => 'info',
	'section'  => 'sakala_footer_menu_section',
	'label'    => __( 'Footer Menu','sakala'),
	'description' => __( 'Click to setup footer menu.','sakala'),
	'linkto' 	=> array(
		'type'=>'panel',
		'value'=>'nav_menus'
	)
) ) );
$wp_customize->selective_refresh->add_partial( 'sakala_footer_menu', array(
	'selector'            => '.footermenu',
	'container_inclusive' => true,
) );

$wp_customize->add_section( 'sakala_footer_copyright_section', array(
	'title' => __('Footer Copyright', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_footer_elements',
	'priority' => sakala_get_section_position( 'sakala_footer_copyright_section','footer' ),
) );

$wp_customize->add_setting( 'sakala_footer_copyright_text', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );

$wp_customize->add_control('sakala_footer_copyright_text', array(
	'type'     => 'textarea',
	'section'  => 'sakala_footer_copyright_section',
	'label'    => __( 'Footer Copyright Text','sakala'),	
) );
$wp_customize->selective_refresh->add_partial( 'sakala_footer_copyright_text', array(
	'selector'            => '.site-info',
	'container_inclusive' => true,
) );


/* social Section */
$wp_customize->add_section( 'sakala_footer_social', array(
	'title' => __('Footer Social', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_footer_elements',
	'priority' => sakala_get_section_position( 'sakala_footer_social','footer'),
) );
$wp_customize->add_setting( 'sakala_footer_social_info', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_integer' 
) );

$wp_customize->add_control( new Info_Custom_Control( $wp_customize, 'sakala_footer_social_info', array(
	'type'     => 'info',
	'section'  => 'sakala_footer_social',
	'label'    => __( 'Footer Social','sakala'),
	'description' => __( 'Go to Header Social to setup footer social icons.','sakala'),
	'linkto' 	=> array(
		'type'=>'section',
		'value'=>'sakala_headersocial_section'
	)
) ) );

$footer_elements_sections_width = array(
	'sakala_footer_menu_section'=>array('footermenu','100'),
	'sakala_footer_copyright_section'=>array('site-info','100'),
	'sakala_footer_social'=>array('site-footer .social-links','100')
);
foreach ($footer_elements_sections_width as $section => $class) {
	$wp_customize->add_setting( $section.'_width', array( 
		'default' 			=> $class[1],
		'transport' => 'postMessage',
		'sanitize_callback' => 'sakala_sanitize_integer' 
	) );
	$wp_customize->add_control( $section.'_width', array(
		'type'     => 'number',
		'section'  => $section,
		'priority' => '5',
		'label'    => __( 'Section Width (%)','sakala'),	
		'description' => __( 'Enter width of the section in percentage.','sakala'),
	) );
}