<?php
/*Add New Panel for header Setups */
$wp_customize->add_panel( 'sakala_header_panel', array (
	'priority' => '20',
	'capability' => 'edit_theme_options',
	'theme_supports' => '',
	'title' => __( 'Header Settings', 'sakala' ),
	'description' => __( 'Setup header of the site.', 'sakala' )
) );

/* Header Section */
$wp_customize->get_section('header_image')->panel = 'sakala_header_panel';
$wp_customize->get_section('header_image')->title = __('Header Background Image','sakala');

$wp_customize->add_section( 'sakala_header_section', array(
	'title' => __('Header Layouts', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_panel',
	'priority' => 10,
) );

$wp_customize->add_setting( 'sakala_header_layout_setting', array( 
	'default' 			=> 'lay0',
	'sanitize_callback' => 'sakala_sanitize_layout' 
) );

$sakala_header_layouts = array('lay0'=>array(
	'image'=> get_template_directory_uri().'/assets/images/sakala-header0.png',
	'name'=>__('Default Layout', 'sakala'),
));
for($i=1;$i<=11;$i++){
	$sakala_header_layouts['lay'.$i] = array(
		'image'=> get_template_directory_uri().'/assets/images/sakala-header'.$i.'.png',
		'name'=>__('Layout ', 'sakala').$i,
	);
}

$wp_customize->add_control( new Image_Radio_Buttons( $wp_customize, 'sakala_header_layout_setting', array(
	'type' => 'image_radio_buttons',
	'label' => __( 'Header Layouts', 'sakala' ),
	'section' => 'sakala_header_section',
	'choices' => $sakala_header_layouts,
	'changednd' => 'change-layout'
) ) );


/** Header Individual Section designs */
$header_sections = array(
	'top_header'=>__('Top Header','sakala'),
	'main_header'=>__('Main Header','sakala'),
	'bottom_header'=>__('Bottom Header','sakala')
);

foreach ($header_sections as $hsec => $htitle) {

	$wp_customize->add_section( 'sakala_'.$hsec.'_section_designs', array(
		'title' => $htitle.' '.__('Designs', 'sakala' ),
		'capability' => 'edit_theme_options',
		'panel' => 'sakala_header_panel',
		'priority' => 10,
	) );

	$wp_customize->add_setting( 'sakala_header_style_'.$hsec, array( 
		'default' 			=> 'sakala-wrapper',
		'sanitize_callback' => 'sakala_sanitize_wrapper' 
	) );

	$wp_customize->add_control( 'sakala_header_style_'.$hsec, array(
		'label'    => $htitle.' '.__( 'Wrapper Style','sakala'),
		'section' => 'sakala_'.$hsec.'_section_designs',
		'type'    => 'select',
		'choices' => array(
			'sakala-wrapper' => esc_html__( 'Wrapped', 'sakala' ),
			'sakala-fullwidth' => esc_html__( 'Fullwidth', 'sakala' ),
		),
	) );

	/* Header */
	$wp_customize->add_setting( 'sakala_header_width_'.$hsec, array( 
		'default' 			=> '1200',
		'transport'			=> 'postMessage',
		'sanitize_callback' => 'sakala_sanitize_integer' 
	) );

	$wp_customize->add_control( new Slider_Control( $wp_customize, 'sakala_header_width_'.$hsec, array(
		'type'     => 'slider_control',
		'section'  => 'sakala_'.$hsec.'_section_designs',
		'label'    => $htitle.' '.__( 'Wrapper Width','sakala'),
		'input_attrs' => array(
			'min'    => 800,
			'max'    => 1920,
			'step'   => 1,
			'suffix' => 'px',
		),
		'active_callback' => 'wrap_sakala_header_style_'.$hsec
	) ) );

	$wp_customize->add_setting( 'sakala_header_bkgcolor_'.$hsec, array( 
		'default' 			=> '',
		'transport' 	=> 'postMessage',
		'sanitize_callback' => 'sakala_sanitize_text' 
	) );

	$wp_customize->add_control( new Customize_Alpha_Color_Control($wp_customize, 'sakala_header_bkgcolor_'.$hsec, array(
		'label'    => $htitle.' '.__( 'Background Color','sakala'),
		'section'  => 'sakala_'.$hsec.'_section_designs',
		'show_opacity'  => true,
		'palette'	=> array(
			'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
			'rgba(50,50,50,0.8)',
			'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
			'#00CC99' // Mix of color types = no problem
		)
	) ) );

	$wp_customize->add_setting( 'sakala_header_marginpadding_'.$hsec, array(
		'default'           => '0, -, 0, -, 0, 0, 0, 0',
		'transport'			=> 'postMessage',
		'sanitize_callback' => 'sakala_sanitize_text',
	) );

	$wp_customize->add_control( new Box_Model( $wp_customize, 'sakala_header_marginpadding_'.$hsec, array(
		'label'       => $htitle.' '.esc_html__( 'Margin and Padding', 'sakala' ),
		'description' => esc_html__( 'Set the default margin and padding.', 'sakala' ),
		'choices'    => array(
			'margin' => array(
				'margin-top'     => '',
				'margin-right'   => '',
				'margin-bottom'  => '',
				'margin-left'    => '',
			),
			'padding' => array(
				'padding-top'    => '20',
				'padding-right'  => '',
				'padding-bottom' => '20',
				'padding-left'   => '',
			),
		),
		'section'     => 'sakala_'.$hsec.'_section_designs',
	) ) );
}

/* Header Elements */

$wp_customize->add_panel( 'sakala_header_elements', array (
	'priority' => '20',
	'capability' => 'edit_theme_options',
	'theme_supports' => '',
	'title' => __( 'Header Elements', 'sakala' ),
	'description' => __( 'Setup Header Elements of the site.', 'sakala' )
) );

/* Add Default Sections to General Panel */
$wp_customize->get_section('title_tagline')->panel = 'sakala_header_elements';
$wp_customize->get_section('title_tagline')->priority = sakala_get_section_position( 'title_tagline' );

$wp_customize->add_section( 'sakala_headermenu_section', array(
	'title' => __('Primary Menu', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headermenu_section' ),
) );

$wp_customize->add_setting( 'sakala_header_menu', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );

$wp_customize->add_control( new Info_Custom_Control( $wp_customize, 'sakala_header_menu', array(
	'type'     => 'info',
	'section'  => 'sakala_headermenu_section',
	'label'    => __( 'Primary Menu','sakala'),
	'description' => __( 'Click to setup primary menu.','sakala'),
	'linkto' 	=> array(
		'type'=>'panel',
		'value'=>'nav_menus'
	)
) ) );

$wp_customize->add_section( 'sakala_headersearch_section', array(
	'title' => __('Search', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headersearch_section' ),
) );
$wp_customize->add_setting( 'sakala_header_search_text', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control('sakala_header_search_text', array(
	'type'     => 'text',
	'section'  => 'sakala_headersearch_section',
	'label'    => __( 'Search Label','sakala'),	
) );
$wp_customize->selective_refresh->add_partial( 'sakala_header_search_text', array(
	'selector'            => '.search-wrapper',
	'container_inclusive' => true,
) );

if(class_exists('woocommerce')){
	$wp_customize->add_section( 'sakala_headercart_section', array(
		'title' => __('Cart Icon', 'sakala' ),
		'capability' => 'edit_theme_options',
		'panel' => 'sakala_header_elements',
		'priority' => sakala_get_section_position( 'sakala_headercart_section' ),
	) );
	$wp_customize->add_setting( 'sakala_header_cart_icon', array( 
		'default' 			=> 'lnr lnr-cart',
		'sanitize_callback' => 'sakala_sanitize_text' 
	) );
	$wp_customize->add_control( 'sakala_header_cart_icon', array(
		'type'     => 'text',
		'section'  => 'sakala_headercart_section',
		'label'    => __( 'Cart Icon Class','sakala'),
		'description'    => __( 'Enter Class of icon like: "fab fa-opencart"','sakala'),
	) );

	$wp_customize->add_setting( 'sakala_header_cart_dropdown', array( 
		'default' 			=> 'yes',
		'sanitize_callback' => 'sakala_sanitize_yesno' 
	) );
	$wp_customize->add_control( 'sakala_header_cart_dropdown', array(
		'type'     => 'radio',
		'section'  => 'sakala_headercart_section',
		'label'    => __( 'Show Header Cart Dropdown','sakala'),
		'description'    => __( 'Show the header cart details dropdown on hover.','sakala'),
		'choices' => array(
			'yes' => __('Yes','sakala'),
			'no' => __('No','sakala')
		)
	) );
	
	$wp_customize->selective_refresh->add_partial( 'sakala_header_cart_icon', array(
		'selector'            => '.cart-wrapper',
		'container_inclusive' => true,
	) );
}

$wp_customize->add_section( 'sakala_headersidemenu_section', array(
	'title' => __('Side Menu Icon', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headersidemenu_section' ),
) );
$wp_customize->add_setting( 'sakala_headersidemenu_widget', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );

$wp_customize->add_control( new Info_Custom_Control( $wp_customize, 'sakala_headersidemenu_widget', array(
	'type'     => 'info',
	'section'  => 'sakala_headersidemenu_section',
	'label'    => __( 'Sidemenu Widgets','sakala'),
	'description' => __( 'Click to setup Sidemenu Contents.','sakala'),
	'linkto' 	=> array(
		'type'=>'section',
		'value'=>'sidebar-widgets-sakala-sidemenuwidget'
	)
) ) );

$wp_customize->selective_refresh->add_partial( 'sakala_headersidemenu_widget', array(
	'selector'            => '.sidewidget-wrapper',
	'container_inclusive' => true,
) );

/* Header Address Sectuion */
$wp_customize->add_section( 'sakala_headeraddress_section', array(
	'title' => __('Header Address', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headeraddress_section' ),
) );

$wp_customize->add_setting( 'sakala_header_address_icon', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_header_address_icon', array(
	'type'     => 'text',
	'section'  => 'sakala_headeraddress_section',
	'label'    => __( 'Address Icon Class','sakala'),
	'description'    => __( 'Enter Class of icon like: "fa fa-location"','sakala'),
) );
$wp_customize->add_setting( 'sakala_header_address', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_header_address', array(
	'type'     => 'textarea',
	'section'  => 'sakala_headeraddress_section',
	'label'    => __( 'Address Text','sakala'),	
	'description' => __( 'This field supports HTML','sakala'),
) );
$wp_customize->selective_refresh->add_partial( 'sakala_header_address_icon', array(
	'selector'            => '.site-address',
	'container_inclusive' => true,
) );

/* Email Section */
$wp_customize->add_section( 'sakala_headeremail_section', array(
	'title' => __('Header Email', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headeremail_section' ),
) );
$wp_customize->add_setting( 'sakala_header_email_icon', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_header_email_icon', array(
	'type'     => 'text',
	'section'  => 'sakala_headeremail_section',
	'label'    => __( 'Email Icon Class','sakala'),
	'description'    => __( 'Enter Class of icon like: "fa fa-envelope"','sakala'),
) );
$wp_customize->add_setting( 'sakala_header_email', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_header_email', array(
	'type'     => 'textarea',
	'section'  => 'sakala_headeremail_section',
	'label'    => __( 'Email Address','sakala'),
) );
$wp_customize->selective_refresh->add_partial( 'sakala_header_email_icon', array(
	'selector'            => '.site-email',
	'container_inclusive' => true,
) );

/* Phone Section */
$wp_customize->add_section( 'sakala_headerphone_section', array(
	'title' => __('Header Phone', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headerphone_section' ),
) );
$wp_customize->add_setting( 'sakala_header_phone_icon', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_header_phone_icon', array(
	'type'     => 'text',
	'section'  => 'sakala_headerphone_section',
	'label'    => __( 'Phone Icon Class','sakala'),
	'description'    => __( 'Enter Class of icon like: "fa fa-phone"','sakala'),
) );
$wp_customize->add_setting( 'sakala_header_phone', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_header_phone', array(
	'type'     => 'textarea',
	'section'  => 'sakala_headerphone_section',
	'label'    => __( 'Phone','sakala'),
) );
$wp_customize->selective_refresh->add_partial( 'sakala_header_phone_icon', array(
	'selector'            => '.site-phone',
	'container_inclusive' => true,
) );

/* social Section */
$wp_customize->add_section( 'sakala_headersocial_section', array(
	'title' => __('Header Social', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headersocial_section' ),
) );


$socials = sakala_social_icons_group();

foreach ($socials as $soc_key=>$soc_label) {	
	$wp_customize->add_setting( 'sakala_header_social_icon_'.$soc_key, array( 
		'default' 			=> '',
		'sanitize_callback' => 'sakala_sanitize_text' 
	) );

	$wp_customize->add_control( 'sakala_header_social_icon_'.$soc_key, array(
		'type'     => 'text',
		'section'  => 'sakala_headersocial_section',
		'label'    => $soc_label.' '.__('Icon' ,'sakala'),	
	) );

	$wp_customize->add_setting( 'sakala_header_social_'.$soc_key, array( 
		'default' 			=> '',
		'sanitize_callback' => 'sakala_sanitize_text' 
	) );

	$wp_customize->add_control( 'sakala_header_social_'.$soc_key, array(
		'type'     => 'text',
		'section'  => 'sakala_headersocial_section',
		'label'    => $soc_label.' '.__('Link' ,'sakala'),	
	) );
}
$wp_customize->selective_refresh->add_partial( 'sakala_header_social_icon_facebook', array(
	'selector'            => '.social-links',
	'container_inclusive' => true,
) );

/* Button Section */
$wp_customize->add_section( 'sakala_headerbutton_section', array(
	'title' => __('Header Button', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headerbutton_section' ),
) );

$wp_customize->add_setting( 'sakala_header_button_text', array( 
	'default' 			=> __('Contact','sakala'),
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_header_button_text', array(
	'type'     => 'text',
	'section'  => 'sakala_headerbutton_section',
	'label'    => __( 'Header Button Text','sakala'),	
) );
$wp_customize->add_setting( 'sakala_header_button_link', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_header_button_link', array(
	'type'     => 'text',
	'section'  => 'sakala_headerbutton_section',
	'label'    => __( 'Header Button Link','sakala'),	
) );
$wp_customize->selective_refresh->add_partial( 'sakala_header_button_text', array(
	'selector'            => '.site-button',
	'container_inclusive' => true,
) );
$wp_customize->add_setting( 'sakala_headerbutton_color', array( 
	'default'     => '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( new Customize_Alpha_Color_Control($wp_customize, 'sakala_headerbutton_color', array(
	'label'    => __('Button Background Color','sakala'),
	'section'  => 'sakala_headerbutton_section',	
	'show_opacity'  => true, // Optional.
	'palette'	=> array(
		'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
		'rgba(50,50,50,0.8)',
		'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
		'#00CC99' // Mix of color types = no problem
	)
) ) );
$wp_customize->add_setting( 'sakala_headerbutton_hover_color', array( 
	'default'     => '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( new Customize_Alpha_Color_Control($wp_customize, 'sakala_headerbutton_hover_color', array(
	'label'    => __( 'Button Hover Background Color','sakala'),
	'section'  => 'sakala_headerbutton_section',
	'show_opacity'  => true, // Optional.
	'palette'	=> array(
		'rgb(150, 50, 220)', // RGB, RGBa, and hex values supported
		'rgba(50,50,50,0.8)',
		'rgba( 255, 255, 255, 0.2 )', // Different spacing = no problem
		'#00CC99' // Mix of color types = no problem
	)
) ) );

/* Header Custom Html Sectuion */
$wp_customize->add_section( 'sakala_headercustom_section', array(
	'title' => __('Custom Html Or Shortcode', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_header_elements',
	'priority' => sakala_get_section_position( 'sakala_headercustom_section' ),
) );

$wp_customize->add_setting( 'sakala_headercustom_icon', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_headercustom_icon', array(
	'type'     => 'text',
	'section'  => 'sakala_headercustom_section',
	'label'    => __( 'Custom Html Icon Class','sakala'),
	'description'    => __( 'Enter Class of icon like: "fa fa-location"','sakala'),
) );
$wp_customize->add_setting( 'sakala_headercustom', array( 
	'default' 			=> '',
	'sanitize_callback' => 'sakala_sanitize_text' 
) );
$wp_customize->add_control( 'sakala_headercustom', array(
	'type'     => 'textarea',
	'section'  => 'sakala_headercustom_section',
	'label'    => __( 'Custom Html or Shortcode','sakala'),	
	'description' => __( 'This field supports HTML or shortocde like: Language: [POLYLANG dropdown=1]','sakala'),
) );

$wp_customize->selective_refresh->add_partial( 'sakala_headercustom_icon', array(
	'selector'            => '.site-customhtml',
	'container_inclusive' => true,
) );

$header_elements_sections_width = array(
	'sakala_headercustom_section'=>array('site-customhtml','10'),
	'sakala_headersocial_section'=>array('social-links','10'),
	'title_tagline'=>array('site-branding','30'),
	'sakala_headeraddress_section'=>array('site-address','10'),
	'sakala_headerphone_section'=>array('site-phone','10'),
	'sakala_headeremail_section'=>array('site-email','10'),
	'sakala_headercart_section'=>array('cart-wrapper','5'),
	'sakala_headersidemenu_section'=>array('sidewidget-wrapper','5'),
	'sakala_headermenu_section'=>array('header-main-menu','70'),
	'sakala_headersearch_section'=>array('search-wrapper','5'),
	'sakala_headerbutton_section'=>array('site-button','10'),
);
foreach ($header_elements_sections_width as $section => $class) {
	$wp_customize->add_setting( $section.'_width', array( 
		'default' 			=> $class[1],
		'transport' => 'postMessage',
		'sanitize_callback' => 'sakala_sanitize_integer' 
	) );
	$wp_customize->add_control( $section.'_width', array(
		'type'     => 'number',
		'section'  => $section,
		'priority' => '5',
		'label'    => __( 'Section Width (%)','sakala'),	
		'description' => __( 'Enter width of the section in percentage.','sakala'),
	) );
}