<?php
/*Add New Panel for Inner Page Setups */
$wp_customize->add_panel( 'sakala_inner_panel', array (
	'priority' => '20',
	'capability' => 'edit_theme_options',
	'theme_supports' => '',
	'title' => __( 'Blog Pages Settings', 'sakala' ),
	'description' => __( 'Setup blog and single page options of the site.', 'sakala' )
) );

/* Blog / Archive Section */
$wp_customize->add_section( 'sakala_inner_blog_section', array(
	'title' => __('Blog Settings', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_inner_panel',
	'priority' => 20,
) );

$wp_customize->add_setting( 'sakala_inner_blog_content_wrap', array( 
	'default' 			=> 'sakala-wrapper',
	'sanitize_callback' => 'sakala_sanitize_wrapper' 
) );

$wp_customize->add_control( 'sakala_inner_blog_content_wrap', array(
	'label'    => __( 'Archive Container Wrapper Style','sakala'),
	'section' => 'sakala_inner_blog_section',
	'type'    => 'select',
	'choices' => array(
		'sakala-wrapper' => esc_html__( 'Wrapped', 'sakala' ),
		'sakala-fullwidth' => esc_html__( 'Fullwidth', 'sakala' ),
	),
) );
$wp_customize->add_setting( 'sakala_inner_blog_content_maxwidth', array( 
	'default' 			=> '1200',
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'sakala_sanitize_integer' 
) );

$wp_customize->add_control( new Slider_Control( $wp_customize, 'sakala_inner_blog_content_maxwidth', array(
	'type'     => 'slider_control',
	'section'  => 'sakala_inner_blog_section',
	'label'    => __( 'Blog Container Width','sakala'),
	'input_attrs' => array(
		'min'    => 0,
		'max'    => 1920,
		'step'   => 1,
		'suffix' => 'px',
	),
	'active_callback' => 'sakala_inner_blog_content_wrapper'
) ) );

$wp_customize->add_setting( 'sakala_inner_blog_sidebar', array( 
	'default' 			=> 'sidebar-right',
	'sanitize_callback' => 'sakala_sanitize_sidebar' 
) );

$wp_customize->add_control( new Image_Radio_Buttons( $wp_customize, 'sakala_inner_blog_sidebar', array(
	'label'    => __( 'Blog / Archive Sidebar Layout','sakala'),
	'section' => 'sakala_inner_blog_section',
	'type'    => 'select',
	'choices' => array(
		'sidebar-left' => array(
			'image'=> get_template_directory_uri().'/assets/images/sidebar-left.png',
			'name'=>__('Left Sidebar', 'sakala')
		),
		'sidebar-right' => array(
			'image'=> get_template_directory_uri().'/assets/images/sidebar-right.png',
			'name'=>__('Right Sidebar', 'sakala')
		),
		'sidebar-none' => array(
			'image'=> get_template_directory_uri().'/assets/images/sidebar-none.png',
			'name'=>__('No Sidebar', 'sakala')
		),
	)
) ) );

$wp_customize->add_setting( 'sakala_inner_blog_content_width', array( 
	'default' 			=> '70',
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'sakala_sanitize_integer' 
) );

$wp_customize->add_control( new Slider_Control( $wp_customize, 'sakala_inner_blog_content_width', array(
	'type'     => 'slider_control',
	'section'  => 'sakala_inner_blog_section',
	'label'    => __( 'Blog Content Width(Primary)','sakala'),
	'input_attrs' => array(
		'min'    => 50,
		'max'    => 100,
		'step'   => 1,
		'suffix' => '%',
	),
) ) );


$wp_customize->add_setting( 'sakala_inner_blog_layout', array( 
	'default' 			=> 'list',
	'sanitize_callback' => 'sakala_sanitize_gridlist' 
) );

$wp_customize->add_control( new Image_Radio_Buttons( $wp_customize, 'sakala_inner_blog_layout', array(
	'label'    => __( 'Blog / Archive Post Style','sakala'),
	'section' => 'sakala_inner_blog_section',
	'type'    => 'select',
	'choices' => array(
		'list' => array(
			'image'=> get_template_directory_uri().'/assets/images/list.jpg',
			'name'=>__('List View', 'sakala')
		),
		'grid' => array(
			'image'=> get_template_directory_uri().'/assets/images/grid.jpg',
			'name'=>__('Grid View', 'sakala')
		),
	)
) ) );

$wp_customize->add_setting( 'sakala_inner_blog_excerpt', array( 
	'default' 			=> '50',
	'sanitize_callback' => 'sakala_sanitize_integer' 
) );

$wp_customize->add_control( 'sakala_inner_blog_excerpt', array(
	'type'    => 'number',
	'label'    => __( 'Blog / Archive Excerpt Length','sakala'),
	'description'    => __( 'Number of Words, will affect the "excerpt_length" hook and overall excerpts.','sakala'),
	'section' => 'sakala_inner_blog_section',
) );

$wp_customize->add_setting( 'sakala_inner_blog_elements', array( 
	'sanitize_callback' => 'sakala_sanitize_text' 
) );

$wp_customize->add_control( new Sakala_Sortable_Elements( $wp_customize, 'sakala_inner_blog_elements', array(
	'label'    => __( 'Post Titles Elements ','sakala'),
	'description'    => __( 'Drag Elements to sort','sakala'),
	'section' => 'sakala_inner_blog_section',
	'choices' => array(
		'0' => array(
			'id'=> 'sakala_titlemeta',
			'name'=>__('Title & Meta', 'sakala'),
			'enable' => '1'
		),
		'1' => array(
			'id'=> 'sakala_thumbnail',
			'name'=>__('Thumbnail', 'sakala'),
			'enable' => '1'
		),
		'2' => array(
			'id'=> 'sakala_excerpt',
			'name'=>__('Excerpt & Read More', 'sakala'),
			'enable' => '1'
		)
	)
) ) );

$wp_customize->add_setting( 'sakala_inner_blog_meta_elements', array( 
	'sanitize_callback' => 'sakala_sanitize_text' 
) );

$wp_customize->add_control( new Sakala_Sortable_Elements( $wp_customize, 'sakala_inner_blog_meta_elements', array(
	'label'    => __( 'Blog Meta Elements ','sakala'),
	'section' => 'sakala_inner_blog_section',
	'choices' => array(
		'0' => array(
			'id'=> 'sakala_author',
			'name'=>__('Author', 'sakala'),
			'enable' => '1'
		),
		'1' => array(
			'id'=> 'sakala_date',
			'name'=>__('Date', 'sakala'),
			'enable' => '1'
		),		
	)
) ) );

/* Single Post/Page Section */
$wp_customize->add_section( 'sakala_inner_single_section', array(
	'title' => __(' Post / Page Settings', 'sakala' ),
	'capability' => 'edit_theme_options',
	'panel' => 'sakala_inner_panel',
	'priority' => 20,
) );

$wp_customize->add_setting( 'sakala_inner_single_content_wrap', array( 
	'default' 			=> 'sakala-wrapper',
	'sanitize_callback' => 'sakala_sanitize_wrapper' 
) );

$wp_customize->add_control( 'sakala_inner_single_content_wrap', array(
	'label'    => __( 'Single Container Wrapper Style','sakala'),
	'section' => 'sakala_inner_single_section',
	'type'    => 'select',
	'choices' => array(
		'sakala-wrapper' => esc_html__( 'Wrapped', 'sakala' ),
		'sakala-fullwidth' => esc_html__( 'Fullwidth', 'sakala' ),
	),
) );
$wp_customize->add_setting( 'sakala_inner_single_content_maxwidth', array( 
	'default' 			=> '1200',
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'sakala_sanitize_integer' 
) );

$wp_customize->add_control( new Slider_Control( $wp_customize, 'sakala_inner_single_content_maxwidth', array(
	'type'     => 'slider_control',
	'section'  => 'sakala_inner_single_section',
	'label'    => __( 'Single Page / Post Container Width','sakala'),
	'input_attrs' => array(
		'min'    => 0,
		'max'    => 1920,
		'step'   => 1,
		'suffix' => 'px',
	),
	'active_callback' => 'sakala_inner_single_content_wrapper'
) ) );

$wp_customize->add_setting( 'sakala_inner_single_sidebar', array( 
	'default' 			=> 'sidebar-right',
	'sanitize_callback' => 'sakala_sanitize_sidebar' 
) );

$wp_customize->add_control( new Image_Radio_Buttons( $wp_customize, 'sakala_inner_single_sidebar', array(
	'label'    => __( 'Single Page / Post Sidebar Layout','sakala'),
	'section' => 'sakala_inner_single_section',
	'type'    => 'select',
	'choices' => array(
		'sidebar-left' => array(
			'image'=> get_template_directory_uri().'/assets/images/sidebar-left.png',
			'name'=>__('Left Sidebar', 'sakala')
		),
		'sidebar-right' => array(
			'image'=> get_template_directory_uri().'/assets/images/sidebar-right.png',
			'name'=>__('Right Sidebar', 'sakala')
		),
		'sidebar-none' => array(
			'image'=> get_template_directory_uri().'/assets/images/sidebar-none.png',
			'name'=>__('No Sidebar', 'sakala')
		),
	)
) ) );

$wp_customize->add_setting( 'sakala_inner_single_content_width', array( 
	'default' 			=> '70',
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'sakala_sanitize_integer' 
) );

$wp_customize->add_control( new Slider_Control( $wp_customize, 'sakala_inner_single_content_width', array(
	'type'     => 'slider_control',
	'section'  => 'sakala_inner_single_section',
	'label'    => __( 'Single Page / Post Content Width (Primary)','sakala'),
	'input_attrs' => array(
		'min'    => 50,
		'max'    => 100,
		'step'   => 1,
		'suffix' => '%',
	),
) ) );

$wp_customize->add_setting( 'sakala_inner_single_meta_elements', array( 
	'sanitize_callback' => 'sakala_sanitize_text' 
) );

$wp_customize->add_control( new Sakala_Sortable_Elements( $wp_customize, 'sakala_inner_single_meta_elements', array(
	'label'    => __( 'Page/ Post Title Elements','sakala'),
	'section' => 'sakala_inner_single_section',
	'choices' => array(
		'0' => array(
			'id'=> 'sakala_titlemeta',
			'name'=>__('Title & Meta', 'sakala'),
			'enable' => '1'
		),
		'1' => array(
			'id'=> 'sakala_thumbnail',
			'name'=>__('Thumbnail', 'sakala'),
			'enable' => '1'
		),
		'2' => array(
			'id'=> 'sakala_content',
			'name'=>__('Content', 'sakala'),
			'enable' => '1'
		),
		'3' => array(
			'id'=> 'sakala_tags',
			'name'=>__('Tags', 'sakala'),
			'enable' => '1'
		),
		'4' => array(
			'id'=> 'sakala_postnav',
			'name'=>__('Post Navigation', 'sakala'),
			'enable' => '1'
		),
		'5' => array(
			'id'=> 'sakala_comments',
			'name'=>__('Comments', 'sakala'),
			'enable' => '1'
		),
	)
) ) );