<?php
/**
 * sakala functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package sakala
 */

define('SAKALA_COMP_URL', get_template_directory_uri() . '/assets/');

if ( ! function_exists( 'sakala_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function sakala_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on sakala, use a find and replace
		 * to change 'sakala' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'sakala', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size('sakala-square', 500, 500, true);


		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'sakala' ),
			'menu-2' => esc_html__( 'Footer', 'sakala' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'sakala_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		add_theme_support( 'editor-color-palette', array(
			array(
				'name'  => esc_html__( 'Orange','sakala' ),
				'slug'  => 'orange',
				'color' => '#E4DAD1',
			),
			array(
				'name'  => esc_html__( 'Red','sakala' ),
				'slug'  => 'red',
				'color' => '#E4D1D1',
			),
			array(
				'name'  => esc_html__( 'Gray','sakala' ),
				'slug'  => 'grey',
				'color' => '#39414D',
			),
			array(
				'name'  => esc_html__( 'Green','sakala' ),
				'slug'  => 'green',
				'color' => '#D1E4DD',
			),
			array(
				'name'  => esc_html__( 'Black','sakala' ),
				'slug'  => 'black',
				'color' => '#000000',
			),
			array(
				'name'  => esc_html__( 'Blue','sakala' ),
				'slug'  => 'blue',
				'color' => '#D1DFE4',
			),
			array(
				'name'  => esc_html__( 'Purple','sakala' ),
				'slug'  => 'purple',
				'color' => '#E4DAD1',
			),
			array(
				'name'  => esc_html__( 'Yellow','sakala' ),
				'slug'  => 'yellow',
				'color' => '#EEEADD',
			),
			array(
				'name'  => esc_html__( 'White','sakala' ),
				'slug'  => 'white',
				'color' =>'#FFFFFF',
			),
		) );


		//Add support for font sizes.
		add_theme_support( 'editor-font-sizes', array(
			array(
				'name'      => esc_html__( 'small', 'sakala' ),
				'shortName' => esc_html__( 'S', 'sakala' ),
				'size'      => 16,
				'slug'      => 'small',
			),
			array(
				'name'      => esc_html__( 'regular', 'sakala' ),
				'shortName' => esc_html__( 'M', 'sakala' ),
				'size'      => 20,
				'slug'      => 'regular',
			),
			array(
				'name'      => esc_html__( 'large', 'sakala' ),
				'shortName' => esc_html__( 'L', 'sakala' ),
				'size'      => 36,
				'slug'      => 'large',
			),
			array(
				'name'      => esc_html__( 'extra larger', 'sakala' ),
				'shortName' => esc_html__( 'XL', 'sakala' ),
				'size'      => 48,
				'slug'      => 'larger',
			),
		) );

		add_theme_support('woocommerce');
	}
endif;
add_action( 'after_setup_theme', 'sakala_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function sakala_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'sakala_content_width', 640 );
}
add_action( 'after_setup_theme', 'sakala_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function sakala_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'sakala' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'sakala' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Sakala SideMenu Contents', 'sakala' ),
		'id'            => 'sakala-sidemenuwidget',
		'description'   => esc_html__( 'Add widgets here.', 'sakala' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
}
add_action( 'widgets_init', 'sakala_widgets_init' );

if (!function_exists('sakala_fonts_url')) :

    /**
     * Register Google fonts for Sakala.
     *
     * @since Sakala 1.0
     *
     * @return string Google fonts URL for the theme.
     */
    function sakala_fonts_url() {
        $fonts_url = '';
        $subsets = 'latin,latin-ext';
        $fonts = $standard_font_family = $default_font_list = $font_family_array = $variants_array = $font_array = $google_fonts = array();

        $customizer_fonts = apply_filters('sakala_customizer_fonts', array(
            'sakala_body_family' => 'Poppins',
            'sakala_menu_family' => 'Oswald',
            'sakala_h_family' => 'Oswald'
        ));
        
        $standard_font = sakala_standard_font_array();
        $google_font_list = sakala_google_font_array();
        $default_font_list = sakala_default_font_array();

        foreach ($standard_font as $key => $value) {
            $standard_font_family[] = $value['family'];
        }

        foreach ($default_font_list as $key => $value) {
            $default_font_family[] = $value['family'];
        }

        foreach ($customizer_fonts as $key => $value) {
            $font_family_array[] = get_theme_mod($key, $value);
        }

        $font_family_array = array_unique($font_family_array);
        $font_family_array = array_diff($font_family_array, array_merge($standard_font_family, $default_font_family));

        foreach ($font_family_array as $font_family) {
            $font_array = sakala_search_key($google_font_list, 'family', $font_family);
            $variants_array = $font_array['0']['variants'];
            $variants_keys = array_keys($variants_array);
            $variants = implode(',', $variants_keys);

            $fonts[] = $font_family . ':' . str_replace('italic', 'i', $variants);
        }
        /*
         * Translators: To add an additional character subset specific to your language,
         * translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language.
         */
        $subset = _x('no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'sakala');

        if ('cyrillic' == $subset) {
            $subsets .= ',cyrillic,cyrillic-ext';
        } elseif ('greek' == $subset) {
            $subsets .= ',greek,greek-ext';
        } elseif ('devanagari' == $subset) {
            $subsets .= ',devanagari';
        } elseif ('vietnamese' == $subset) {
            $subsets .= ',vietnamese';
        }

        if ($fonts) {
            $fonts_url = add_query_arg(array(
                'family' => urlencode(implode('|', $fonts)),
                'subset' => urlencode($subsets),
                'display' => 'swap',
                    ), '//fonts.googleapis.com/css');
        }

        return $fonts_url;
    }

endif;
/**
 * Enqueue scripts and styles.
 */
function sakala_scripts() {

	wp_enqueue_style( 'dashicons' );
	wp_enqueue_style( 'linearicons', get_template_directory_uri().'/assets/css/linearicons.css', array(), '1.0.0' );

	$query_args = array('family' => 'Rubik:300,400,500,600,700,800|Barlow:300,400,500,600,700|Roboto+Slab:200,300,400,500,600|Noto+Sans:400,700');

  	wp_enqueue_style('sakala-font-style', add_query_arg($query_args, "//fonts.googleapis.com/css"));

	wp_enqueue_style( 'sakala-style', get_stylesheet_uri() );

	wp_enqueue_style( 'sakala-keybaord', get_template_directory_uri() . '/assets/css/keyboard.css', array() );

	wp_enqueue_style( 'font-awesome', get_template_directory_uri(). '/assets/css/fontawesome/font-awesome.min.css', array(), '4.7.0', true );

	wp_enqueue_script( 'sakala-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'sakala-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	wp_enqueue_script( 'sakala-custom', get_template_directory_uri() . '/assets/js/sakala-frontscript.js', array('jquery'), '20191109', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'sakala_scripts' );


function sakala_add_editor_styles(){
	
    add_editor_style( get_template_directory_uri().'/assets/css/editor-style.css' );

}
add_action( 'admin_init', 'sakala_add_editor_styles' );

function sakala_gutenberg_styles() {
	
	wp_enqueue_style( 'sakala-style', get_template_directory_uri() . '/assets/css/editor-style.css', array() );
}
add_action( 'enqueue_block_editor_assets', 'sakala_gutenberg_styles' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/assets/components/typography/typography.php';


/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Extended options from _s theme.
 */
require get_template_directory() . '/assets/sakala-functions.php';



//dynamic css
require get_template_directory() . '/inc/dynamic-css.php';


